/*
 * Copyright (c) 2012, David Bolding
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


/**
 * Until at least fv01879 we're in black-and-white.
 * OK, it looks like an fvNNNNN link is always available, and always in black-and-white.
 * So what I'm thinking I can do is try requesting an fcNNNNN.png link, and if that flops,
 *   try fvNNNNN.gif for black-and-white.
 */

const site_url = "http://freefall.purrsia.com/";
const init_url = site_url + "default.htm";


// I really don't like this use of a global variable.
const Stage = {
    Before : 0,
    Color  : 1,
    Gray   : 2
}

var current_stage;


/**
 * ripped from http://www.electrictoolbox.com/pad-number-zeroes-javascript/
 */
function _zero_pad(number, length)
{
    var str = '' + number;
    while (str.length < length) {
        str = '0' + str;
    }

    return str;
}


/**
 * Comic 1879 goes in section 1900
 * Comic 1800 goes in section 1800
 */
function _get_section_str(comic_number)
{
    var sec = Math.ceil(comic_number / 100) * 100;
    return '' + sec;
}


function _get_url_for_pnum(comic_number, color)
{
    var lastString = _zero_pad(comic_number, 5);
    var secString = _get_section_str(comic_number);

    var currString = site_url + "ff" + secString;
    if (color == true) {
        currString += "/fc";
    } else {
        currString += "/fv";
    }
    currString += lastString + ".htm";

    return currString;
}


function init()
{
    comic.comicAuthor = "Mark Stanly";
    comic.websiteUrl = site_url;
    
    comic.requestPage(init_url, comic.User);
}


/**
 * Complication: like a lot of comics, there isn't an ``archivev-style'' link
 *   for the current comic.
 */

/**
 * I still don't get how this thing generates the URL for a new comic page
 *   and how it initiates the request.
 * If I request page 100 (and the current's in the thousands, and 100 is uncached),
 *   what happens?
 * I assume we get into pageRetrieved, but with what arguments?
 * What's in data and where did it come from?
 *
 * Maybe it *always* makes a User request and parses the main page,
 *   but then in my code I either generate a request for a specific page
 *   or scrape the main page.
 * OK, working on that assumption and it seems to behave.
 * So, whenever any page number is requested, it makes a User request.
 * If it's a first-run request -- right after init() -- then no page number is set.
 * If it is, then a comic number is set, and we get into that logic.
 *
 * I feel  like that should have been laid out explicitly in the tutorial somewhere.
 * Or maybe it is and I just can't read.
 */


function pageRetrieved(id, data)
{
    if (id == comic.User) {
        const expLast = new RegExp("src=\"/ff\\d+/f[vc](\\d+)");

        const matchLast = expLast.exec(data);
        if (matchLast == null) {
            comic.error();
            return;
        }

        comic.lastIdentifier = matchLast[1];

        current_stage = Stage.Color;

        if (comic.identifierSpecified) {
            // Handle special case if the specified identifier is the
            //   current comic.
            if (comic.identifier == comic.lastIdentifier) {
                comic.requestPage(init_url, comic.Page);
                return;
            }

            currString = _get_url_for_pnum(comic.identifier, true);

            comic.requestPage(currString, comic.Page);
        } else {
            comic.requestPage(init_url, comic.Page);
        }

    } else if (id == comic.Page) {
        /* Need to handle either parsing main page
         *   or an index page.
         * Fortunately, it looks like the same regex will work for both.
         */

        print("-- comic.Page request");

        // Try matching the image url in the link
        const expImage = new RegExp("<A HREF=\"/(ff\\d+/f[vc]\\d+\.\\w+)\"");

        const imageMatch = expImage.exec(data);
        if (imageMatch == null) {
            if (current_stage == Stage.Color) {
                current_stage = Stage.Gray;
                currString = _get_url_for_pnum(comic.identifier, false);
                comic.requestPage(currString, comic.Page);
            } else {
                current_stage = Stage.Before;
                comic.error();
            }
            return;
        }

        print("-- IMAGE:    " + imageMatch[1]);
        comic.requestPage(site_url + imageMatch[1], comic.Image);

        // Normally I'd build the tital now, but these comics don't have titles.
    }
}



