/***************************************************************************
 *                           BSD Licensed                                  *
 *                                                                         *
 *                    So, Commence tha Jigglin'                            *
 ***************************************************************************/


/**
 * They often do more than one post a day, so we can't use the date engine.
 * And they're not addressable by date, anyway (i.e. we have no way to
 *   build a URL from a date).
 * They also don't have meaningful numbers (i.e. the numbers aren't consecutive).
 * The best I can think of doing is just using a String engine and using
 *   either the full URL or the post number as the ID.
 * Which I am not at all happy with; if any other human being ever reads
 *   this text and has a better idea, please tell me!
 * Or, you know, implement it!
 */
 

const RssUrl = 'http://feeds.feedburner.com/leasthelpful';
const PostPrefix = 'http://leasthelpful.com/post/';
const ImagePrefix = 'http://leasthelpful.com/image/';


function init()
{
    comic.comicAuthor = "Hudson Hongo";

    if (comic.identifier == new String()) {
        // No identifier given - fetch RSS feed, find current page
        comic.websiteUrl = "http://leasthelpful.com/";
        comic.requestPage(RssUrl, comic.User);
    } else { 
        // Identifier given, build appropriate URL and fetch
        comic.websiteUrl = PostPrefix + comic.identifier;
        comic.requestPage(comic.websiteUrl, comic.Page);
    }

    return;
}
 
function pageRetrieved(id, data)
{
    if (id == comic.User) {
        const post_regex = new RegExp('origLink>http://leasthelpful.com/post/([^<]+)<');

        var match = post_regex.exec(data);

        if (match == null) {
            comic.error();
            return;
        }

        comic.lastIdentifier = match[1];
        comic.identifer = match[1]; // might be mis-placed
        comic.requestPage(PostPrefix + match[1], comic.Page);

        return;
    }

    if (id == comic.Page) {
        // Find the image
        // The 'http://leasthelpful.com/image/(\\d+)' url is not an image, but an HTML page that\
        //   embeds the image.

        const image_regex = new RegExp('(http://.+\\.media\\.tumblr\\.com[^"]+)');

        var image_match = image_regex.exec(data);

        if (image_match == null) {
            comic.error();
            return;
        }


        // Extract the next and previous links
        // matches:
        //   <a href="http://leasthelpful.com/post/42773447358" style="float:left">« Previous Entry</a>
		//   <a href="http://leasthelpful.com/post/42932894072" style="float:right">Next Entry »</a>

        const prev_regex = new RegExp('<a href="http://leasthelpful.com/post/(\\d+)" style="float:left">« Previous Entry</a>');
        var prev_match = prev_regex.exec(data);
        if (prev_match != null) {
            comic.previousIdentifier = prev_match[1];
        }

        // Shorter, less-specific regexes match too early and consume too much
        const next_regex = new RegExp('<a href="http://leasthelpful.com/post/(\\d+)" style="float:right">Next Entry »</a>');
        var next_match = next_regex.exec(data);
        if (next_match != null) {
            comic.nextIdentifier = next_match[1];
        }


        // Fetch the image
        comic.requestPage(image_match[1], comic.Image);


        return;
    }

}

