/*
 *   Copyright (C) 2009 Mathias Panzenböck <grosser.meister.morti@gmx.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Library General Public License version 2 as
 *   published by the Free Software Foundation
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details
 *
 *   You should have received a copy of the GNU Library General Public
 *   License along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

const daUser      = 'panzi';
const comicAuthor = 'Mathias Panzenböck';
const firstId     = 'Mozilla-Clouds-645485';
const firstNumId  = '645485';

const GetLast     = comic.User;
const GetPrevNext = comic.User + 1;
const mainPage    = 'http://' + daUser + '.deviantart.com/';
const comicPrefix = mainPage + 'art/';
const navPrefix   = 'http://' + daUser + '.deviantart.com/global/resourcenav?q=sort%3Atime+gallery%3A' +
                    daUser + '&link=http%3A%2F%2F' + daUser + '.deviantart.com%2Fgallery%2F';
const navPrev     = navPrefix + '&go=1&rid=1%3A';
const navNext     = navPrefix + '&go=-1&rid=1%3A';

function init() {
	comic.comicAuthor     = comicAuthor;
	comic.firstIdentifier = firstId;
	comic.shopUrl         = 'http://' + daUser + '.deviantart.com/prints/';
	
	if (comic.identifierSpecified) {
		var match, url;
		if ((match = /^(.*)-prev$/.exec(comic.identifier)) != null) {
			url = navPrev + match[1];
		}
		else if ((match = /^(.*)-next$/.exec(comic.identifier)) != null) {
			url = navNext + match[1];
		}
		else {
			url = comicPrefix + comic.identifier;
		}
		comic.requestPage(url, comic.Page);
	}
	else {
		comic.requestPage(mainPage, GetLast);
	}
}

function pageRetrieved(id, data) {
	if (id == comic.Image) {
		return;
	}

	// find the most recent strip
	if (id == GetLast) {
		var re = new RegExp('<a class="t" href="http:\/\/' + daUser + '.deviantart.com\/art\/([^"]*)"');
		var match = re.exec(data);
		if (match != null) {
			comic.lastIdentifier = comic.identifier = match[1];
			comic.requestPage(comicPrefix + comic.identifier, comic.Page);
		}
		else {
			print('*** error parsing latest comic');
			comic.error();
		}
	}
	else {
		var re = /<img id='zoomed-in-image' [^>]*src="([^"]*)"/;
		var match = re.exec(data);
		var imgUrl;

		if (match == null) {
			print('*** error parsing comic: ' + comic.identifier + ' using kate logo as fallback');
			imgUrl = 'http://kate-editor.org/themes/garland/logo.png';
		}
		else {
			imgUrl = match[1];
		}

		// get title
		re = new RegExp('<title>(.*) by .' + daUser + ' on deviantART<\/title>');
		match = re.exec(data);
		if (match != null) {
			comic.title = match[1];
		}

		// get description
		var i = data.search('<div class="text block pppt">');
		if (i != -1) {
			var descr = data.substring(i);
			i = descr.search('</div>');
			if (i != -1) {
				descr = descr.substr(0, i + 6);
			}
			descr = descr.replace(/<img src="http:\/\/e\.deviantart\.\w+\/emoticons\/[^"]*" [^>]*alt="([^"]*)"[^>]*>/g, '$1');
			comic.additionalText = descr;
		}

		// get prev and next link
		var re = new RegExp('<input type="hidden" name="ref" value="http:\/\/' +
			daUser + '\.deviantart.com\/art\/([^"]*-(\\d+))"\/>');
		var match = re.exec(data);

		if (match == null) {
			print('*** error parsing previous/next id for: ' + comic.identifier);
			return;
		}

		var comicId = match[1];
		var numId   = match[2];


		if (numId != firstNumId) {
			comic.previousIdentifier = numId + '-prev';
		}

		comic.nextIdentifier = numId + '-next';
		
		comic.websiteUrl = comicPrefix + comicId;

		// get image
		comic.requestPage(imgUrl, comic.Image);
	}
}
